==> modconf_0.2.43.tar.gz: modconf-0.2.43/modconf.8.pl <==
.\" dummy line
.TH MODCONF 8 "10 marca 1998" Linux "Obsuga moduw w Debianie"
.UC 4
.SH NAZWA
modconf \- narzdzie konfiguracji moduw
.SH SKADNIA
.B modconf
[--source [floppy|mounted]]
[--target miejsce_przeznaczenia]
[--libdir cieka]
[--restrict-section dzia]*
[--exclude-section dzia]*
[--load-before modu]*
[--load-only modu]*
[--load-after modu]*
.br
.SH OPIS
.I modconf
to skrypt sucy do instalacji moduw jdra Linux. Mona go uywa
interaktywnie (tryb GUI), lub z linii komend (tryb wsadowy).
.SH OPCJE
Opcje zaznaczone poniej "*" s stosowane wobec tylko jednego moduu.
Jeli chcesz zastosowac je wobec wiekszej iloci moduw, powtrz opcj
na linii komend.
.TP
.I \--source floppy|mounted
Wskazuje skd maj zosta pobrane moduy. Opcja \fBfloppy\fR (dyskietka) jest
uywana przy instalacji Linuksa. Opcja \fBmounted\fR jest uywana przy
zainstalowanym ju systemie i jest ona stosowana domylnie.
.TP
.I --target katalog 
Okrela gdzie w systemie znajduj si pliki 
.I etc/modules
i
.I etc/modules.conf
(domylnie: / ). Nazwy katalogu nie naley konczy znakiem "/".
.TP
.I \--libdir cieka
Okrela gdzie w systemie znajduj si pliki
.I eval
i
.I descr.gz
(domylnie: /usr/lib/module_help). Nazwy katalogu nie naley konczy znakiem "/".
.TP
.I \--restrict-section dzia*
ogranicza program \fBmodconf\fR wycznie do okrelonego dziau 
.I /lib/modules
.TP
.I \--exclude-section dzia*
zmusza program \fBmodconf\fR do zignorowania danego dziau 
.I /lib/modules
.br

Dostpne w czasie pisania tego dokumentu dziay to:
.B block
.B cdrom
.B fs
.B ipv4
.B ipv6
.B misc
.B net
.B scsi
(mog by tam take inne dziay w przypadku zainstalowania pakietw ze
specjalnymi moduami, np. pcmcia-modules).
.TP
.I \--load-before modu*
dany \fBmodu\fR ma zosta zaadowany \fBprzed\fR wszystkimi innymi.
.TP
.I \--load-only modu*
dany \fBmodu\fR ma zosta zaadowany po podanych opcj \fB--load-before\fR.
Wycza tryb interaktywny.
.TP
.I \--load-after modu*
dany \fBmodu\fR ma zosta zaadowany po podanych opcj \fB--load-before\fR.
.br
Ta opcja zostaje 
.B zignorowana
w przypadku podania rwnie poprzedniej opcji.
.SH PRZYKADY
.PP
Ponisze przykady \fBnie zostay przetestowane\fR
.TP
modconf --load-only plip --load-before ip_masq_ftp --load-only appletalk
.TP
aduje moduy "ip_masq_ftp", "plip" oraz "appletalk", w takiej kolejnoci, i nie uruchamia programu interaktywnego.
.SH AUTOR
.B modconf
zosta napisany przez Bruce'a Perens'a <bruce@pixar.com>.
.br
Due zmiany wprowadzi Sven Rudolph <sr1@inf.tu-dresden.de>.
.br
Wicej zmian wprowadzi Enrique Zanardi <ezanardi@ull.es>.
.br
I jeszcze troch - Randolph Chung <tausq@debian.org>.
.P
Ta strona podrcznika zostaa napisana przez Antonio Vieiro Varela
<antonio@faraday.usc.es>, a przetumaczona na jzyk polski przez Marcina
Owsianego <porridge@debian.org>.
.SH BDY
Brak znanych.
.SH PATRZ TE
\fBinsmod\fP(1), \fBmodprobe\fP(1), \fBdepmod\fP(1), \fBlsmod\fP(1),
\fBrmmod\fP(1), \fBmodules\fP(2), \fBkerneld\fP(8).

==> modconf_0.2.45.1.tar.gz: modconf-0.2.45.1/modconf.8.pl <==
.\" dummy line
.TH MODCONF 8 "10 marca 1998" Linux "Obsuga moduw w Debianie"
.UC 4
.SH NAZWA
modconf \- narzdzie konfiguracji moduw
.SH SKADNIA
.B modconf
[--source [floppy|mounted]]
[--target miejsce_przeznaczenia]
[--libdir cieka]
[--restrict-section dzia]*
[--exclude-section dzia]*
[--load-before modu]*
[--load-only modu]*
[--load-after modu]*
.br
.SH OPIS
.I modconf
to skrypt sucy do instalacji moduw jdra Linux. Mona go uywa
interaktywnie (tryb GUI), lub z linii komend (tryb wsadowy).
.SH OPCJE
Opcje zaznaczone poniej "*" s stosowane wobec tylko jednego moduu.
Jeli chcesz zastosowac je wobec wiekszej iloci moduw, powtrz opcj
na linii komend.
.TP
.I \--source floppy|mounted
Wskazuje skd maj zosta pobrane moduy. Opcja \fBfloppy\fR (dyskietka) jest
uywana przy instalacji Linuksa. Opcja \fBmounted\fR jest uywana przy
zainstalowanym ju systemie i jest ona stosowana domylnie.
.TP
.I --target katalog 
Okrela gdzie w systemie znajduj si pliki 
.I etc/modules
i
.I etc/modules.conf
(domylnie: / ). Nazwy katalogu nie naley konczy znakiem "/".
.TP
.I \--libdir cieka
Okrela gdzie w systemie znajduj si pliki
.I eval
i
.I descr.gz
(domylnie: /usr/share/modconf). Nazwy katalogu nie naley konczy znakiem "/".
.TP
.I \--restrict-section dzia*
ogranicza program \fBmodconf\fR wycznie do okrelonego dziau 
.I /lib/modules
.TP
.I \--exclude-section dzia*
zmusza program \fBmodconf\fR do zignorowania danego dziau 
.I /lib/modules
.br

Dostpne w czasie pisania tego dokumentu dziay to:
.B block
.B cdrom
.B fs
.B ipv4
.B ipv6
.B misc
.B net
.B scsi
(mog by tam take inne dziay w przypadku zainstalowania pakietw ze
specjalnymi moduami, np. pcmcia-modules).
.TP
.I \--load-before modu*
dany \fBmodu\fR ma zosta zaadowany \fBprzed\fR wszystkimi innymi.
.TP
.I \--load-only modu*
dany \fBmodu\fR ma zosta zaadowany po podanych opcj \fB--load-before\fR.
Wycza tryb interaktywny.
.TP
.I \--load-after modu*
dany \fBmodu\fR ma zosta zaadowany po podanych opcj \fB--load-before\fR.
.br
Ta opcja zostaje 
.B zignorowana
w przypadku podania rwnie poprzedniej opcji.
.SH PRZYKADY
.PP
Ponisze przykady \fBnie zostay przetestowane\fR
.TP
modconf --load-only plip --load-before ip_masq_ftp --load-only appletalk
.TP
aduje moduy "ip_masq_ftp", "plip" oraz "appletalk", w takiej kolejnoci, i nie uruchamia programu interaktywnego.
.SH AUTOR
.B modconf
zosta napisany przez Bruce'a Perens'a <bruce@pixar.com>.
.br
Due zmiany wprowadzi Sven Rudolph <sr1@inf.tu-dresden.de>.
.br
Wicej zmian wprowadzi Enrique Zanardi <ezanardi@ull.es>.
.br
I jeszcze troch - Randolph Chung <tausq@debian.org>.
.P
Ta strona podrcznika zostaa napisana przez Antonio Vieiro Varela
<antonio@faraday.usc.es>, a przetumaczona na jzyk polski przez Marcina
Owsianego <porridge@debian.org>.
.SH BDY
Brak znanych.
.SH PATRZ TE
\fBinsmod\fP(1), \fBmodprobe\fP(1), \fBdepmod\fP(1), \fBlsmod\fP(1),
\fBrmmod\fP(1), \fBmodules\fP(2), \fBkerneld\fP(8).
